summaryrefslogtreecommitdiff
path: root/src/diag.rs
diff options
context:
space:
mode:
authorKian-Meng Ang <kianmeng.ang@gmail.com>2023-03-22 16:02:51 +0800
committerGitHub <noreply@github.com>2023-03-22 09:02:51 +0100
commit25acefeb5b0cf0977ad01fe3128d494d9617a2cf (patch)
tree5f629b2aee909022be2be674a60d10fe59bc77c3 /src/diag.rs
parent26f4321a5e9eb56b905ca9eee9cf52422c7ff859 (diff)
Fix typos (#115)
Found via `codespell -S target -L crate,ist,thi,alle,dedented,ue,tung,nd,ende,overriden,dependant`
Diffstat (limited to 'src/diag.rs')
-rw-r--r--src/diag.rs10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/diag.rs b/src/diag.rs
index b12df209..c1a7c834 100644
--- a/src/diag.rs
+++ b/src/diag.rs
@@ -112,16 +112,16 @@ impl Display for Tracepoint {
fn fmt(&self, f: &mut Formatter) -> fmt::Result {
match self {
Tracepoint::Call(Some(name)) => {
- write!(f, "error occured in this call of function `{}`", name)
+ write!(f, "error occurred in this call of function `{}`", name)
}
Tracepoint::Call(None) => {
- write!(f, "error occured in this function call")
+ write!(f, "error occurred in this function call")
}
Tracepoint::Show(name) => {
- write!(f, "error occured while applying show rule to this {name}")
+ write!(f, "error occurred while applying show rule to this {name}")
}
Tracepoint::Import => {
- write!(f, "error occured while importing this module")
+ write!(f, "error occurred while importing this module")
}
}
}
@@ -180,7 +180,7 @@ where
/// A result type with a file-related error.
pub type FileResult<T> = Result<T, FileError>;
/// An error that occured while trying to load of a file.
#[derive(Debug, Clone, Eq, PartialEq, Hash)]
pub enum FileError {
/// A file was not found at this path.
@@ -180,7 +180,7 @@ where
/// A result type with a file-related error.
pub type FileResult<T> = Result<T, FileError>;
-/// An error that occured while trying to load of a file.
+/// An error that occurred while trying to load of a file.
#[derive(Debug, Clone, Eq, PartialEq, Hash)]
pub enum FileError {